==> clutternomore-1.1.3%2B1.21.1-fabric-sources.jar: dev/tazer/clutternomore/common/blocks/VerticalSlabBlock.java <==
package dev.tazer.clutternomore.common.blocks;

import com.mojang.serialization.MapCodec;
import net.minecraft.class_10;
import net.minecraft.class_1657;
import net.minecraft.class_1750;
import net.minecraft.class_1799;
import net.minecraft.class_1922;
import net.minecraft.class_1936;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2383;
import net.minecraft.class_243;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_2753;
import net.minecraft.class_3610;
import net.minecraft.class_3611;
import net.minecraft.class_3612;
import net.minecraft.class_3726;
import net.minecraft.class_3737;
import net.minecraft.class_4970;
import org.jetbrains.annotations.Nullable;

public class VerticalSlabBlock extends class_2383 implements class_3737 {
    //? if >1.20.1 {
    public static final MapCodec<? extends VerticalSlabBlock> CODEC = method_54094(VerticalSlabBlock::new);
    //?}
    public static final class_2746 DOUBLE = class_2746.method_11825("double");
    public static final
    //? if >1.21.2 {
    /*EnumProperty<Direction>
    *///?} else {
    class_2753
    //?}
    FACING = class_2741.field_12481;
    public static final class_2746 WATERLOGGED = class_2741.field_12508;

    public VerticalSlabBlock(class_4970.class_2251 properties) {
        super(properties);
        method_9590(field_10647.method_11664().method_11657(DOUBLE, false).method_11657(field_11177, class_2350.field_11043).method_11657(WATERLOGGED, false));
    }

    //? if >1.20.1 {
    @Override
    protected MapCodec<? extends VerticalSlabBlock> method_53969() {
        return field_46280;
    }
    //?}

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(DOUBLE).method_11667(field_11177).method_11667(WATERLOGGED);
    }

    @Override
    public class_2680 method_9605(class_1750 context) {
        class_2338 pos = context.method_8037();
        class_243 exactPos = context.method_17698();
        class_2350 direction = context.method_8042();
        class_2680 replacingBlockState = context.method_8045().method_8320(pos);
        class_3610 replacingFluidState = context.method_8045().method_8316(pos);

        if (replacingBlockState.method_27852(this)) {
            return replacingBlockState.method_11657(DOUBLE, true);
        }

        class_2680 stateForPlacement = method_9564().method_11657(WATERLOGGED, replacingFluidState.method_15772() == class_3612.field_15910);

        switch (direction) {
            case field_11043 -> {
                if (exactPos.field_1350 - pos.method_10260() > 0.5) direction = direction.method_10153();
            }
            case field_11035 -> {
                if (exactPos.field_1350 - pos.method_10260() < 0.5) direction = direction.method_10153();
            }
            case field_11034 -> {
                if (exactPos.field_1352 - pos.method_10263() < 0.5) direction = direction.method_10153();
            }
            case field_11039 -> {
                if (exactPos.field_1352 - pos.method_10263() > 0.5) direction = direction.method_10153();
            }
        }

        return stateForPlacement.method_11657(field_11177, direction);
    }

    @Override
    //? if >1.20.1 {
    protected
    //?} else {
    /*public
    *///?}
    boolean method_9616(class_2680 state, class_1750 context) {
        class_1799 itemStack = context.method_8041();
        if (state.method_11654(DOUBLE) || !(itemStack.method_31574(method_8389())) ) {
            return false;
        }

        if (!context.method_7717()) {
            return true;
        }

        double hitposX = context.method_17698().field_1352 - context.method_8037().method_10263();
        double hitposZ = context.method_17698().field_1350 - context.method_8037().method_10260();

        class_2350 facingDirection = state.method_11654(field_11177);
        return switch (facingDirection) {
            case field_11043 -> hitposZ >= 0.5;
            case field_11034 -> hitposX <= 0.5;
            case field_11035 -> hitposZ <= 0.5;
            case field_11039 -> hitposX >= 0.5;
            default -> false;
        };
    }

    @Override
    public class_265 method_9530(class_2680 state, class_1922 level, class_2338 pos, class_3726 context) {
        if(state.method_11654(DOUBLE)) {
            return class_259.method_1077();
        }
        
        return switch (state.method_11654(field_11177)) {
            case field_11043 -> class_259.method_31943(0, 0, 0, 1, 1, 0.5F);
            case field_11034 -> class_259.method_31943(0.5F, 0, 0, 1, 1, 1);
            case field_11035 -> class_259.method_31943(0, 0, 0.5F, 1, 1, 1);
            case field_11039 -> class_259.method_31943(0, 0, 0, 0.5F, 1, 1);
            default -> class_259.method_1077();
        };
    }

    @Override
    //? if >1.21.2 {
    /*protected BlockState updateShape(BlockState state, LevelReader level, ScheduledTickAccess scheduledTickAccess, BlockPos pos, Direction direction, BlockPos blockPos2, BlockState blockState2, RandomSource randomSource) {
        if (state.getValue(WATERLOGGED)) {
            scheduledTickAccess.scheduleTick(pos, Fluids.WATER, Fluids.WATER.getTickDelay(level));
        }

        return super.updateShape(state, level, scheduledTickAccess, pos, direction, blockPos2, blockState2, randomSource);
    }
    *///?} else {
    //? if >1.20.1 {
    protected
    //?} else {
    /*public
    *///?}
    class_2680 method_9559(class_2680 state, class_2350 direction, class_2680 neighborState, class_1936 level, class_2338 pos, class_2338 neighborPos) {
    if (state.method_11654(WATERLOGGED)) {
            level.method_39281(pos, class_3612.field_15910, class_3612.field_15910.method_15789(level));
        }

        return super.method_9559(state, direction, neighborState, level, pos, neighborPos);
    }
    //?}

    @Override
    public boolean method_9526(class_2680 state) {
        return !state.method_11654(DOUBLE);
    }

    @Override
    public class_3610 method_9545(class_2680 state) {
        if (state.method_11654(WATERLOGGED)) {
            return class_3612.field_15910.method_15729(false);
        }
        
        return state.method_26227();
    }

    @Override
    public boolean method_10311(class_1936 level, class_2338 pos, class_2680 state, class_3610 fluidState) {
        if (!state.method_11654(DOUBLE)) {
            return class_3737.super.method_10311(level, pos, state, fluidState);
        }

        return false;
    }

    @Override
    //? if >1.21.2 {
    /*public boolean canPlaceLiquid(@Nullable LivingEntity player, BlockGetter level, BlockPos pos, BlockState state, Fluid fluid) {
    *///?} else if 1.21.1 {
    public boolean method_10310(@Nullable class_1657 player, class_1922 level, class_2338 pos, class_2680 state, class_3611 fluid) {
    //?} else if 1.20.1 {
    /*public boolean canPlaceLiquid(BlockGetter level, BlockPos pos, BlockState state, Fluid fluid) {
    *///?}
        if (!state.method_11654(DOUBLE)) {
            //? if >1.20.1 {
            return class_3737.super.method_10310(player, level, pos, state, fluid);
            //?} else {
            /*return SimpleWaterloggedBlock.super.canPlaceLiquid(level, pos, state, fluid);
            *///?}
        }
        return false;
    }

    @Override
    //? if >1.20.1 {
    protected
    //?} else {
    /*public
    *///?}
    boolean method_9516(
            //? if >1.20.1 {
            class_2680 state, class_10 type
            //?} else {
            /*BlockState state, BlockGetter level, BlockPos pos, PathComputationType type
            *///?}
    ) {
        return state.method_11654(DOUBLE);
    }
}

==> clutternomore-1.1.4%2B1.21.8-fabric-sources.jar: dev/tazer/clutternomore/common/blocks/VerticalSlabBlock.java <==
package dev.tazer.clutternomore.common.blocks;

import com.mojang.serialization.MapCodec;
import net.minecraft.class_10;
import net.minecraft.class_10225;
import net.minecraft.class_1309;
import net.minecraft.class_1750;
import net.minecraft.class_1799;
import net.minecraft.class_1922;
import net.minecraft.class_1936;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2383;
import net.minecraft.class_243;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_2754;
import net.minecraft.class_3610;
import net.minecraft.class_3611;
import net.minecraft.class_3612;
import net.minecraft.class_3726;
import net.minecraft.class_3737;
import net.minecraft.class_4538;
import net.minecraft.class_4970;
import net.minecraft.class_5819;
import org.jetbrains.annotations.Nullable;

public class VerticalSlabBlock extends class_2383 implements class_3737 {
    //? if >1.20.1 {
    public static final MapCodec<? extends VerticalSlabBlock> CODEC = method_54094(VerticalSlabBlock::new);
    //?}
    public static final class_2746 DOUBLE = class_2746.method_11825("double");
    public static final
    //? if >1.21.2 {
    class_2754<class_2350>
    //?} else {
    /*DirectionProperty
    *///?}
    FACING = class_2741.field_12481;
    public static final class_2746 WATERLOGGED = class_2741.field_12508;

    public VerticalSlabBlock(class_4970.class_2251 properties) {
        super(properties);
        method_9590(field_10647.method_11664().method_11657(DOUBLE, false).method_11657(field_11177, class_2350.field_11043).method_11657(WATERLOGGED, false));
    }

    //? if >1.20.1 {
    @Override
    protected MapCodec<? extends VerticalSlabBlock> method_53969() {
        return field_46280;
    }
    //?}

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(DOUBLE).method_11667(field_11177).method_11667(WATERLOGGED);
    }

    @Override
    public class_2680 method_9605(class_1750 context) {
        class_2338 pos = context.method_8037();
        class_243 exactPos = context.method_17698();
        class_2350 direction = context.method_8042();
        class_2680 replacingBlockState = context.method_8045().method_8320(pos);
        class_3610 replacingFluidState = context.method_8045().method_8316(pos);

        if (replacingBlockState.method_27852(this)) {
            return replacingBlockState.method_11657(DOUBLE, true);
        }

        class_2680 stateForPlacement = method_9564().method_11657(WATERLOGGED, replacingFluidState.method_15772() == class_3612.field_15910);

        switch (direction) {
            case field_11043 -> {
                if (exactPos.field_1350 - pos.method_10260() > 0.5) direction = direction.method_10153();
            }
            case field_11035 -> {
                if (exactPos.field_1350 - pos.method_10260() < 0.5) direction = direction.method_10153();
            }
            case field_11034 -> {
                if (exactPos.field_1352 - pos.method_10263() < 0.5) direction = direction.method_10153();
            }
            case field_11039 -> {
                if (exactPos.field_1352 - pos.method_10263() > 0.5) direction = direction.method_10153();
            }
        }

        return stateForPlacement.method_11657(field_11177, direction);
    }

    @Override
    //? if >1.20.1 {
    protected
    //?} else {
    /*public
    *///?}
    boolean method_9616(class_2680 state, class_1750 context) {
        class_1799 itemStack = context.method_8041();
        if (state.method_11654(DOUBLE) || !(itemStack.method_31574(method_8389())) ) {
            return false;
        }

        if (!context.method_7717()) {
            return true;
        }

        double hitposX = context.method_17698().field_1352 - context.method_8037().method_10263();
        double hitposZ = context.method_17698().field_1350 - context.method_8037().method_10260();

        class_2350 facingDirection = state.method_11654(field_11177);
        return switch (facingDirection) {
            case field_11043 -> hitposZ >= 0.5;
            case field_11034 -> hitposX <= 0.5;
            case field_11035 -> hitposZ <= 0.5;
            case field_11039 -> hitposX >= 0.5;
            default -> false;
        };
    }

    @Override
    public class_265 method_9530(class_2680 state, class_1922 level, class_2338 pos, class_3726 context) {
        if(state.method_11654(DOUBLE)) {
            return class_259.method_1077();
        }
        
        return switch (state.method_11654(field_11177)) {
            case field_11043 -> class_259.method_31943(0, 0, 0, 1, 1, 0.5F);
            case field_11034 -> class_259.method_31943(0.5F, 0, 0, 1, 1, 1);
            case field_11035 -> class_259.method_31943(0, 0, 0.5F, 1, 1, 1);
            case field_11039 -> class_259.method_31943(0, 0, 0, 0.5F, 1, 1);
            default -> class_259.method_1077();
        };
    }

    @Override
    //? if >1.21.2 {
    protected class_2680 method_9559(class_2680 state, class_4538 level, class_10225 scheduledTickAccess, class_2338 pos, class_2350 direction, class_2338 blockPos2, class_2680 blockState2, class_5819 randomSource) {
        if (state.method_11654(WATERLOGGED)) {
            scheduledTickAccess.method_64312(pos, class_3612.field_15910, class_3612.field_15910.method_15789(level));
        }

        return super.method_9559(state, level, scheduledTickAccess, pos, direction, blockPos2, blockState2, randomSource);
    }
    //?} else {
    /*//? if >1.20.1 {
    protected
    //?} else {
    /^public
    ^///?}
    BlockState updateShape(BlockState state, Direction direction, BlockState neighborState, LevelAccessor level, BlockPos pos, BlockPos neighborPos) {
    if (state.getValue(WATERLOGGED)) {
            level.scheduleTick(pos, Fluids.WATER, Fluids.WATER.getTickDelay(level));
        }

        return super.updateShape(state, direction, neighborState, level, pos, neighborPos);
    }
    *///?}

    @Override
    public boolean method_9526(class_2680 state) {
        return !state.method_11654(DOUBLE);
    }

    @Override
    public class_3610 method_9545(class_2680 state) {
        if (state.method_11654(WATERLOGGED)) {
            return class_3612.field_15910.method_15729(false);
        }
        
        return state.method_26227();
    }

    @Override
    public boolean method_10311(class_1936 level, class_2338 pos, class_2680 state, class_3610 fluidState) {
        if (!state.method_11654(DOUBLE)) {
            return class_3737.super.method_10311(level, pos, state, fluidState);
        }

        return false;
    }

    @Override
    //? if >1.21.2 {
    public boolean method_10310(@Nullable class_1309 player, class_1922 level, class_2338 pos, class_2680 state, class_3611 fluid) {
    //?} else if 1.21.1 {
    /*public boolean canPlaceLiquid(@Nullable Player player, BlockGetter level, BlockPos pos, BlockState state, Fluid fluid) {
    *///?} else if 1.20.1 {
    /*public boolean canPlaceLiquid(BlockGetter level, BlockPos pos, BlockState state, Fluid fluid) {
    *///?}
        if (!state.method_11654(DOUBLE)) {
            //? if >1.20.1 {
            return class_3737.super.method_10310(player, level, pos, state, fluid);
            //?} else {
            /*return SimpleWaterloggedBlock.super.canPlaceLiquid(level, pos, state, fluid);
            *///?}
        }
        return false;
    }

    @Override
    //? if >1.20.1 {
    protected
    //?} else {
    /*public
    *///?}
    boolean method_9516(
            //? if >1.20.1 {
            class_2680 state, class_10 type
            //?} else {
            /*BlockState state, BlockGetter level, BlockPos pos, PathComputationType type
            *///?}
    ) {
        return state.method_11654(DOUBLE);
    }
}
